parse_version

Function parse_version 

pub fn parse_version(s: &str, loose: bool) -> Result<(Version, String), Error>
Parse a version string, optionally accepting a loose leading prefix.

Returns the parsed version and the captured prefix (empty when strict or none).