pub struct SQLiteQueryBuilder {
pub db_path: PathBuf,
pub table_name: String,
pub sql_select: Option<String>,
pub sql_where: Option<String>,
pub sql_params: Vec<String>,
pub sql_order_by: Option<String>,
pub sql_limit: Option<i64>,
pub column_adapters: BTreeMap<String, SQLiteColumnAdapter>,
/* private fields */
}Expand description
A lazy query builder for SQLite tables, allowing SQL pushdown optimizations
for commands like length, select, first, and last.
Fields
db_path: PathBuftable_name: Stringsql_select: Option<String>sql_where: Option<String>sql_params: Vec<String>sql_order_by: Option<String>sql_limit: Option<i64>column_adapters: BTreeMap<String, SQLiteColumnAdapter>Implementations
Sourceimpl SQLiteQueryBuilder
impl SQLiteQueryBuilder
pub fn new(db_path: PathBuf, table_name: String, signals: Signals) -> Self
pub fn with_select(self, select: String) -> Self
pub fn with_where(self, where_clause: String, params: Vec<String>) -> Self
pub fn with_order_by(self, order_by: String) -> Self
pub fn with_limit(self, limit: i64) -> Self
pub fn with_column_adapter( self, column_name: String, adapter: SQLiteColumnAdapter, ) -> Self
Sourcepub fn with_unix_millis_datetime_column(self, column_name: String) -> Self
pub fn with_unix_millis_datetime_column(self, column_name: String) -> Self
Register a datetime adapter for a column containing Unix epoch milliseconds.
Sourcepub fn with_millis_duration_column(self, column_name: String) -> Self
pub fn with_millis_duration_column(self, column_name: String) -> Self
Register a duration adapter for a column containing milliseconds.
Sourcepub fn project_output_columns(&self, columns: &[String]) -> Option<Self>
pub fn project_output_columns(&self, columns: &[String]) -> Option<Self>
Projects a subset of output columns from the current SELECT list.
This is used by filter pushdowns (for example, history | select command) where
Nushell refers to post-alias output names, but the underlying SQLite table may have
different source column names.
Example:
- current projection:
command_line as command, duration_ms as duration - requested output:
command - rewritten projection:
command_line as command
If a requested output name cannot be mapped unambiguously to the existing projection,
this returns None so callers can safely fall back to non-pushdown behavior.
This method intentionally does not parse full SQL grammar; it relies on a small, conservative parser that is sufficient for projections we generate internally.
pub fn build_sql(&self) -> String
pub fn execute(&self, call_span: Span) -> Result<PipelineData, ShellError>
pub fn count(&self, call_span: Span) -> Result<i64, ShellError>